@@ -180,17 +180,17 @@ int main(int argc, char **argv) {
             }
           }
           if (is_command_file) {
-            bool allow_main_ = false;
+            bool is_main_ = false;
             gmic gi(0,0,false,0,0,(gmic_pixel_type)0);
-            gi.add_commands(gmic_file,argv[1],is_debug,0,0,&allow_main_);
-            if (allow_main_ && argc==3) { // Check if command '_main_' has arguments
+            gi.add_commands(gmic_file,argv[1],is_debug,0,0,&is_main_);
+            if (is_main_ && argc==3) { // Check if command '_main_' has arguments
               const unsigned int hash = (int)gmic::hashcode("_main_",false);
               unsigned int ind = 0;
               if (gmic::search_sorted("_main_",gi.command_names[hash],
                                       gi.command_names[hash].size(),ind)) // Command found
-                allow_main_ = (bool)gi.command_has_arguments[hash](ind,0);
+                is_main_ = (bool)gi.command_has_arguments[hash](ind,0);
             }
-            gmic_instance.allow_main_ = allow_main_;
+            gmic_instance.allow_main_ = is_main_;
           }
           std::fclose(gmic_file);
         }
